
Kong
====

Kong is a simple interface to Kongregate (http://www.kongregate.com/)
statistics. It was originally written to provide 360 Kid-style statistics
reporting, as a small boredom-based project, and has not really grown since
its inception.

Usage
-----

>>> import kong
>>> api = kong.Kongregate()
>>> user = kong.User(api, "MostAwesomeDude")

Bugs
----

No bugs currently known. Feel free to email the author or open new bugs on
github.

License
-------

Kong and all other files in this package are available under the terms of the
MIT X11 license, reproduced in COPYING and also in the library.
